==> amarok-2.1.80.tar.bz2: amarok-2.1.80/src/playlist/navigators/FavoredRandomTrackNavigator.h <==
/****************************************************************************************
 * Copyright (c) 2009 Edward Toroshchin <edward.hades@gmail.com>                        *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) version 3 or        *
 * any later version accepted by the membership of KDE e.V. (or its successor approved  *
 * by the membership of KDE e.V.), which shall act as a proxy defined in Section 14 of  *
 * version 3 of the license.                                                            *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef FAVOREDRANDOMTRACKNAVIGATOR_H
#define FAVOREDRANDOMTRACKNAVIGATOR_H

#include "TrackNavigator.h"

namespace Playlist
{

class FavoredRandomTrackNavigator : public TrackNavigator
{
public:
    FavoredRandomTrackNavigator() : TrackNavigator() { }

    quint64 requestNextTrack();
    quint64 requestUserNextTrack() { return requestNextTrack(); }
    quint64 requestLastTrack();

    void reset();

private:
    QList< quint64 > m_history;
};

}

#endif

==> amarok-2.3.0.tar.bz2: amarok-2.3.0/src/playlist/navigators/FavoredRandomTrackNavigator.h <==
/****************************************************************************************
 * Copyright (c) 2009 Edward Toroshchin <edward.hades@gmail.com>                        *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) version 3 or        *
 * any later version accepted by the membership of KDE e.V. (or its successor approved  *
 * by the membership of KDE e.V.), which shall act as a proxy defined in Section 14 of  *
 * version 3 of the license.                                                            *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef FAVOREDRANDOMTRACKNAVIGATOR_H
#define FAVOREDRANDOMTRACKNAVIGATOR_H

#include "TrackNavigator.h"

namespace Playlist
{

class FavoredRandomTrackNavigator : public TrackNavigator
{
public:
    FavoredRandomTrackNavigator() : TrackNavigator(), m_random(0) { }

    quint64 likelyNextTrack();
    quint64 likelyLastTrack();

    quint64 requestNextTrack();
    quint64 requestUserNextTrack() { return requestNextTrack(); }
    quint64 requestLastTrack();

    void reset();

private:
    int randomRow();
    QList< quint64 > m_history;
    int m_random;
};

}

#endif
